@@ -130,11 +130,10 @@ class MetricCheck:
 
             # Step 6: Build final result
             # For backward compatibility, use first detection as primary
-            # TODO: Update CheckResult model to support multiple detections
             primary_detection = detections[0] if detections else DetectionResult(
                 metric_name=metric_name,
                 timestamp=datapoint.timestamp,
-                value=datapoint.value,
+                value=datapoint.value or 0.0,
                 is_anomaly=False,
                 score=0.0,
             )
@@ -143,8 +142,11 @@ class MetricCheck:
                 metric_name=metric_name,
                 datapoint=datapoint,
                 detection=primary_detection,
+                timestamp=datapoint.timestamp,
+                value=datapoint.value or 0.0,
                 alert_sent=alert_sent,
                 alert_reason=alert_reason,
+                detections=detections,  # Include all detections
                 errors=errors,
             )
 
@@ -178,6 +180,8 @@ class MetricCheck:
                     is_anomaly=False,
                     score=0.0,
                 ),
+                timestamp=execution_time,
+                value=0.0,
                 alert_sent=False,
                 errors=errors,
             )
